@@ -479,8 +479,9 @@ get_player_recent_matches <- function(player = NULL, rank = NULL, category = NUL
                                             scrape()
         ## Find html table
         recent_result <- current_page %>%
-                              html_nodes("table") %>%
-                              .[[4]] %>%
+                              html_nodes("table")
+
+        recent_result <- suppressWarnings(recent_result[str_detect(recent_result, "match_summary_table")][[1]]) %>%
                               html_table() %>%
                               filter(row_number() != n()) %>%
                               as_tibble() %>%
@@ -532,8 +533,9 @@ get_player_recent_matches <- function(player = NULL, rank = NULL, category = NUL
 
         ## Find html table
         recent_result <- current_page %>%
-                              html_nodes("table") %>%
-                              .[[4]] %>%
+                              html_nodes("table")
+
+        recent_result <- suppressWarnings(recent_result[str_detect(recent_result, "match_summary_table")][[1]]) %>%
                               html_table() %>%
                               filter(row_number() != n()) %>%
                               as_tibble() %>%
